@@ -3,7 +3,7 @@ package Getopt::Long::Util;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-10'; # DATE
 our $DIST = 'Getopt-Long-Util'; # DIST
-our $VERSION = '0.894'; # VERSION
+our $VERSION = '0.895'; # VERSION
 
 use 5.010001;
 use strict;
@@ -140,15 +140,20 @@ $SPEC{humanize_getopt_long_opt_spec} = {
 Convert <pm:Getopt::Long> option specification into a more human-friendly
 notation that is suitable for including in help/usage text, for example:
 
-    help|h|?       ->  --help, -h, -?
-    help|h|?       ->  --help | -h | -?  (if you provide 'separator')
-    --foo=s        ->  --foo=s
-    --foo=s        ->  --foo=somelabel  (if you provide 'value_label')
-    --foo:s        ->  --foo[=s]
-    --foo=s@       ->  --foo=s+
-    --foo=s%       ->  --foo key=value
-    --foo=s        ->  --foo=somelabel  (if you provide 'value_label')
-    --debug!       ->  --(no)debug
+    help|h|?       ->  "--help, -h, -?"
+    help|h|?       ->  "--help | -h | -?"               # if you provide 'separator')
+    --foo=s        ->  "--foo=s"
+    --foo=s        ->  "--foo=somelabel"                # if you provide 'value_label'
+    --foo:s        ->  "--foo[=s]"
+    --foo=s@       ->  "(--foo=s)+"
+    --foo=s%       ->  "(--foo key=value)+"
+    --foo=s%       ->  "(--foo somelabel1=somelabel2)+" # if you provide 'key_label' and 'value_label'
+    --debug!       ->  "--(no)debug"
+
+It also produces POD-formatted string for use in POD documentation:
+
+    --foo=s        ->  {plaintext=>"--foo=s", pod=>"B<--foo>=I<s>"}
+                                                        # if you set 'extended' to true
 
 Will die if can't parse the optspec string.
 
@@ -178,7 +183,7 @@ _
     args_as => 'array',
     result_naked => 1,
     result => {
-        schema => 'str*',
+        schema => ['any*', {of=>[['str*'], ['hash*', {of=>'str*'}]]}],
     },
 };
 sub humanize_getopt_long_opt_spec {
@@ -422,7 +427,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.894 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2021-07-10.
+This document describes version 0.895 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2021-07-10.
 
 =head1 CONTRIBUTOR
 
@@ -529,20 +534,25 @@ Return value:  (hash)
 
 Usage:
 
- humanize_getopt_long_opt_spec( [ \%optional_named_args ] , $optspec) -> str
+ humanize_getopt_long_opt_spec( [ \%optional_named_args ] , $optspec) -> str|hash
 
 Convert L<Getopt::Long> option specification into a more human-friendly
 notation that is suitable for including in help/usage text, for example:
 
- help|h|?       ->  --help, -h, -?
- help|h|?       ->  --help | -h | -?  (if you provide 'separator')
- --foo=s        ->  --foo=s
- --foo=s        ->  --foo=somelabel  (if you provide 'value_label')
- --foo:s        ->  --foo[=s]
- --foo=s@       ->  --foo=s+
- --foo=s%       ->  --foo key=value
- --foo=s        ->  --foo=somelabel  (if you provide 'value_label')
- --debug!       ->  --(no)debug
+ help|h|?       ->  "--help, -h, -?"
+ help|h|?       ->  "--help | -h | -?"               # if you provide 'separator')
+ --foo=s        ->  "--foo=s"
+ --foo=s        ->  "--foo=somelabel"                # if you provide 'value_label'
+ --foo:s        ->  "--foo[=s]"
+ --foo=s@       ->  "(--foo=s)+"
+ --foo=s%       ->  "(--foo key=value)+"
+ --foo=s%       ->  "(--foo somelabel1=somelabel2)+" # if you provide 'key_label' and 'value_label'
+ --debug!       ->  "--(no)debug"
+
+It also produces POD-formatted string for use in POD documentation:
+
+ --foo=s        ->  {plaintext=>"--foo=s", pod=>"B<--foo>=I<s>"}
+                                                     # if you set 'extended' to true
 
 Will die if can't parse the optspec string.
 
@@ -567,7 +577,7 @@ If set to true, will return a hash of multiple formats instead of a single plain
 
 =back
 
-Return value:  (str)
+Return value:  (str|hash)
 
 
 
@@ -666,7 +676,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
